# SlangPy Experiments

This folder contains experiments we've been working on to test out features of SlangPy. They make some great
demos of what can be done with it, but may contain workarounds and aren't guarunteed to be completely
up to date with latest code.

| Name                                          | Output                                                        | Description                                                                                                                                                                                                                                           |
| -------                                       | ------------                                                  | -----------------------------------------                                                                                                                                                                                                             |
| brdf                                          |                                                               | Ray trace an analytic sphere with a full PBR based BRDF                                                                                                                                                                                               |
| [diff-splatting](diff-splatting/README.md)    | <img src="diff-splatting/example-image.png" height="100">     | This algorithm represents a simplified version of the 3D Gaussian Splatting algorithm detailed in this paper (https://repo-sam.inria.fr/fungraph/3d-gaussian-splatting/).                                                                             |
| fwd-rasterizer                                |                                                               | Simple computer shader based rasterization of a triangle                                                                                                                                                                                              |
| sdf-match                                     |                                                               | Use gradient descent to learn SDF parameters of a sphere                                                                                                                                                                                              |
| tiny-bc                                       |                                                               | Slang based BC7 compressor                                                                                                                                                                                                                            |

